@@ -15,3 +15,12 @@
 #' @format A character vector with 56,238 Ensembl IDs.
 #' @source \url{https://www.gtexportal.org}
 'gtexv6p'
+
+#' Ensembl IDs from GTEx V7 Gene Read Count Data
+#'
+#' A dataset containing the Ensembl IDs from GTEx (V7)
+#' gene read count data.
+#'
+#' @format A character vector with 56,202 Ensembl IDs.
+#' @source \url{https://www.gtexportal.org}
+'gtexv7'
